catchAll property
Whether the domain uses catch-all email addresses.
true means the domain accepts all emails regardless of the local part.
null means this could not be determined.
Implementation
final bool? catchAll;
Whether the domain uses catch-all email addresses.
true means the domain accepts all emails regardless of the local part.
null means this could not be determined.
final bool? catchAll;