confidence property
Confidence level: 'High', 'Medium', or 'Low'.
Indicates how confident the validation system is in the result.
Implementation
final String? confidence;
Confidence level: 'High', 'Medium', or 'Low'.
Indicates how confident the validation system is in the result.
final String? confidence;