disposable property
Whether the email is from a disposable/temporary email service.
Disposable emails are typically used for temporary signups and should be rejected in production applications.
Implementation
final bool disposable;
Whether the email is from a disposable/temporary email service.
Disposable emails are typically used for temporary signups and should be rejected in production applications.
final bool disposable;