smtpValid property
Whether SMTP verification was successful.
This indicates that the mail server confirmed the email address exists.
Implementation
final bool smtpValid;
Whether SMTP verification was successful.
This indicates that the mail server confirmed the email address exists.
final bool smtpValid;