TempMailMessages class

Utility class for generating mocking messages when temporary/disposable emails are detected.

Constructors

TempMailMessages()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

messageCount int
Total number of available messages.
no setter

Static Methods

getAllMessages() List<String>
Gets all available mocking messages.
getMessage(int index) String
Gets a specific message by index (0-14).
getRandomMessage() String
Gets a random mocking message for temporary email detection.