BulkValidationRequest class
Request model for creating a bulk email validation job.
Used internally by MailValidationClient.createBulkJob.
Constructors
-
BulkValidationRequest({required List<
String> emails, String? name}) -
Creates a new BulkValidationRequest.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this request to a JSON map for API submission.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited