BulkSummary class
Summary statistics for a bulk validation job.
Provides quick overview of validation results without needing to iterate through all individual results.
Constructors
- BulkSummary({required int total, required int valid, required int invalid, required int processed})
-
Creates a new BulkSummary.
const
-
BulkSummary.fromJson(Map<
String, dynamic> json) -
Creates a BulkSummary from a JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalid → int
-
Number of invalid emails found.
final
- processed → int
-
Number of emails that were successfully processed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
Total number of emails in the job.
final
- valid → int
-
Number of valid emails found.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited