cached property
Whether this result was retrieved from cache.
true means this email was validated before and the cached result
was returned (no credits were consumed).
false or null means this was a new validation.
Implementation
final bool? cached;